﻿/* ICircuitBranch.cs
 * 
 * Copyright (C) 2015 E.Togashi
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

namespace Popolo.HVAC.Circuit
{
  /// <summary>回路網の流路</summary>
  public interface ICircuitBranch: ImmutableCircuitBranch
  {
    /// <summary>上流節点を設定・取得する</summary>
    new CircuitNode UpStreamNode { get; set; }

    /// <summary>下流節点を設定・取得する</summary>
    new CircuitNode DownStreamNode { get; set; }

    /// <summary>前後差圧から体積流量[m3/s]を計算する</summary>
    /// <returns>体積流量[m3/s]</returns>
    void UpdateFlowRateFromNodePressureDifference();
  }

  /// <summary>回路網の流路</summary>
  public interface ImmutableCircuitBranch
  {
    /// <summary>上流節点を取得する</summary>
    CircuitNode UpStreamNode { get; }

    /// <summary>下流節点を取得する</summary>
    CircuitNode DownStreamNode { get; }

    /// <summary>流量[m3/s]を取得する</summary>
    double VolumetricFlowRate { get; }
  }

}
