﻿/* Matrix.cs
 * 
 * Copyright (C) 2015 E.Togashi
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

namespace Popolo.Numerics.MatrixOperation
{
  /// <summary>行列</summary>
  public class Matrix : IMatrix
  {
    /// <summary>行列</summary>
    private double[,] matrix;

    /// <summary>行数を取得する</summary>
    public int Rows { get { return matrix.GetLength(0); } }

    /// <summary>列数を取得する</summary>
    public int Columns { get { return matrix.GetLength(1); } }

    /// <summary>要素の値を設定・取得する</summary>
    /// <param name="row">行番号</param>
    /// <param name="column">列番号</param>
    /// <returns>要素の値値</returns>
    public double this[int row, int column]
    {
      get { return matrix[row, column]; }
      set { matrix[row, column] = value; }
    }

    /// <summary>コンストラクタ</summary>
    /// <param name="rowSize">行数</param>
    /// <param name="columnSize">列数</param>
    public Matrix(int rowSize, int columnSize)
    { matrix = new double[rowSize, columnSize]; }

    /// <summary>初期化する</summary>
    /// <param name="val">初期化する値</param>
    public void Initialize(double val)
    {
      for (int i = 0; i < matrix.GetLength(0); i++)
        for (int j = 0; j < matrix.GetLength(1); j++)
          matrix[i, j] = val;
    }
  }
}
