﻿/* IShadingDevice.cs
 * 
 * Copyright (C) 2016 E.Togashi
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

namespace Popolo.ThermalLoad
{
  /// <summary>窓ガラス中空層の日射遮蔽物</summary>
  public interface IShadingDevice
  {

    /// <summary>有効か否か</summary>
    bool Pulldowned { get; set; }

    /// <summary>光学特性に変化があるか否か</summary>
    bool HasPropertyChanged { get; }

    /// <summary>見かけの太陽高度[radian]を設定・取得する</summary>
    double ProfileAngle { get; set; }

    /// <summary>光学特性を計算する</summary>
    /// <param name="isDiffuseIrradianceProperties">拡散日射か否か</param>
    /// <param name="irradianceFromSideF">F側開口からの日射か否か</param>
    /// <param name="transmittance">透過率[-]</param>
    /// <param name="reflectance">反射率[-]</param>
    void ComputeOpticalProperties
      (bool isDiffuseIrradianceProperties, bool irradianceFromSideF,
      out double transmittance, out double reflectance);

  }

  /// <summary>常に透過率100%の日射遮蔽物</summary>
  public class EmptyShadingDevice : IShadingDevice
  {
    /// <summary>有効か否か</summary>
    public bool Pulldowned { get; set; }

    /// <summary>光学特性に変化があるか否か</summary>
    public bool HasPropertyChanged { get; private set; }

    /// <summary>見かけの太陽高度[radian]を設定・取得する</summary>
    public double ProfileAngle { get; set; }

    /// <summary>新しいインスタンスを初期化する</summary>
    public EmptyShadingDevice() { HasPropertyChanged = true; }

    /// <summary>光学特性を計算する</summary>
    /// <param name="isDiffuseIrradianceProperties">拡散日射か否か</param>
    /// <param name="irradianceFromSideF">F側開口からの日射か否か</param>
    /// <param name="transmittance">透過率[-]</param>
    /// <param name="reflectance">反射率[-]</param>
    public void ComputeOpticalProperties
      (bool isDiffuseIrradianceProperties, bool irradianceFromSideF,
      out double transmittance, out double reflectance)
    {
      transmittance = 1.0;
      reflectance = 0.0;
      HasPropertyChanged = false;
    }
  }

}
